bsb_hdf5 package
================================

Submodules
----------

bsb_hdf5.chunks module
--------------------------------------

.. automodule:: bsb_hdf5.chunks
   :members:
   :undoc-members:

bsb_hdf5.connectivity\_set module
-------------------------------------------------

.. automodule:: bsb_hdf5.connectivity_set
   :members:
   :undoc-members:

bsb_hdf5.file\_store module
-------------------------------------------

.. automodule:: bsb_hdf5.file_store
   :members:
   :exclude-members: FileStore
   :undoc-members:

bsb_hdf5.morphology\_repository module
------------------------------------------------------

.. automodule:: bsb_hdf5.morphology_repository
   :members:
   :undoc-members:

bsb_hdf5.placement\_set module
----------------------------------------------

.. automodule:: bsb_hdf5.placement_set
   :members:
   :undoc-members:

bsb_hdf5.resource module
----------------------------------------

.. automodule:: bsb_hdf5.resource
   :members:
   :undoc-members:

Module contents
---------------

.. automodule:: bsb_hdf5
   :members:
   :undoc-members:
